**1.2.0**

- Support virtualenv 16 and 15
- Added wheel distribution to PyPI.
- Improved packaging (setup.cfg) and tox configuration
- Announced deprecation for Python 2.7

**1.1.0**

- `Droped support for virtualenv<15 <https://github.com/PolicyStat/terrarium/pull/66>`_
- `Droped support for python 2.6 <https://github.com/PolicyStat/terrarium/pull/66>`_
- `Added support for pip>=10 <https://github.com/PolicyStat/terrarium/pull/66>`_
- `Added support for latest version of virtualenv <https://github.com/PolicyStat/terrarium/pull/66>`_

**1.0.1**

- `Support latest 2 versions of virtualenv <https://github.com/PolicyStat/terrarium/pull/61>`_

**1.0.0**

- `Support for Google Cloud Storage, in addition to Amazon S3 <https://github.com/PolicyStat/terrarium/pull/53>`_
- `Preserve order of requirements <https://github.com/PolicyStat/terrarium/pull/59>`_

**1.0.0-rc.6**

- `shlex comments=True breaks remote source requirements <https://github.com/PolicyStat/terrarium/pull/52>`_

**1.0.0-rc.5**

- `Fixed some spelling and grammar in the README <https://github.com/PolicyStat/terrarium/pull/34>`_
- `Added "Tips" Section to README <https://github.com/PolicyStat/terrarium/pull/40>`_
- `Permit inline comments in requirements files <https://github.com/PolicyStat/terrarium/pull/41>`_
- `Added tox.ini for tox <https://github.com/PolicyStat/terrarium/pull/38>`_
- `Deprecate python 2.5 <https://github.com/PolicyStat/terrarium/pull/44>`_
- `Update travis configuration to use tox <https://github.com/PolicyStat/terrarium/pull/45>`_
- `Update documentation to use sphinx <https://github.com/PolicyStat/terrarium/pull/46>`_
- `Update version number in only one place <https://github.com/PolicyStat/terrarium/pull/47>`_
- `Moved README content to sphinx docs <https://github.com/PolicyStat/terrarium/pull/49>`_

**1.0.0-rc.4**

- `Add support for pip 1.3.1 <https://github.com/PolicyStat/terrarium/issues/31>`_
- `Add command to restore backup <https://github.com/PolicyStat/terrarium/issues/28>`_
- `Added --require-download option <https://github.com/PolicyStat/terrarium/issues/32>`_

**1.0.0-rc.3**

- `Don't print S3 secret key in verbose mode / debug level <https://github.com/PolicyStat/terrarium/issues/25>`_
- `Update requirements to include support for virtualenv 1.8.4 and others <https://github.com/PolicyStat/terrarium/issues/21>`_
- `Fixed mac compatibility issues because of bsd tar  <https://github.com/PolicyStat/terrarium/issues/19>`_
- `Improvements for tests <https://github.com/PolicyStat/terrarium/issues/18>`_
- `Pip 1.2 compatibility <https://github.com/PolicyStat/terrarium/issues/17>`_
- `Handle comments in requirements files <https://github.com/PolicyStat/terrarium/issues/16>`_
- `Output when boto not installed is confusing <https://github.com/PolicyStat/terrarium/issues/15>`_
- `Output on normal install makes it feel like terrarium hung <https://github.com/PolicyStat/terrarium/issues/13>`_
- `--storage-dir should default to environment variable TERRARIUM_STORAGE_DIR <https://github.com/PolicyStat/terrarium/issues/10>`_
- `Gracefully handle permission failures when creating environment backup  <https://github.com/PolicyStat/terrarium/issues/9>`_


**1.0.0-rc.2**

- `Cannot call rmtree on a symbolic link <https://github.com/PolicyStat/terrarium/issues/6>`_
- `Dangling symlink on extract <https://github.com/PolicyStat/terrarium/issues/5>`_

**1.0.0-rc.1**

- `boto.S3Connection should be boto.s3.connection.S3Connection <https://github.com/PolicyStat/terrarium/issues/4>`_
- `Terrarium needs to fix paths after upload <https://github.com/PolicyStat/terrarium/issues/3>`_
- `Implement options as described in README spec <https://github.com/PolicyStat/terrarium/issues/1>`_
